@@ -1,22 +1,24 @@
 package CatalystX::Features::Feature;
+our $VERSION = '0.11';
+
 use Moose;
 use Path::Class;
 use Catalyst::Utils;
 
-has 'backend' => ( is=>'ro', isa=>'CatalystX::Features::Role::Backend', required=>1 );
+has 'backend' => ( is=>'ro', isa=>'CatalystX::Features::Role::Backend', weak_ref=>1, required=>1 );
 
-has 'id' => ( is=>'rw', isa=>'Str' );
-has 'name' => ( is=>'rw', isa=>'Str' );
-has 'version' => ( is=>'rw', isa=>'Str', default=>'1.0.0' );
-has 'path' => ( is=>'rw', isa=>'Str', trigger=> \&_build_args );
+has 'id'      => ( is => 'rw', isa => 'Str' );
+has 'name'    => ( is => 'rw', isa => 'Str' );
+has 'version' => ( is => 'rw', isa => 'Str', default => 'max' );
+has 'path'    => ( is => 'rw', isa => 'Str', trigger => \&_build_from_path );
 
-has 'root' => ( is=>'rw', isa=>'Str' );
-has 'lib' => ( is=>'rw', isa=>'Str' );
-has 't' => ( is=>'rw', isa=>'Str' );
+has 'root' => ( is => 'rw', isa => 'Str' );
+has 'lib'  => ( is => 'rw', isa => 'Str' );
+has 't'    => ( is => 'rw', isa => 'Str' );
 
 with 'CatalystX::Features::Role::Feature';  # the interface role, place after 'has'
 
-sub _build_args {
+sub _build_from_path {
     my ($self, $value ) = @_;
 
     my $path = $self->path; 
@@ -40,7 +42,7 @@ sub version_number {
     if( $version =~ /\./ ) {
         my $number;
         foreach my $part ( split /\./, $version ) {
-            $number .= sprintf("%03d", $part );
+            $number .= sprintf("%099d", $part );
         }
         return $number;
     } else {
@@ -65,7 +67,7 @@ CatalystX::Features::Feature - Class that represents a single feature.
 
 =head1 VERSION
 
-version 0.1011
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -81,19 +83,19 @@ This is the object you get when you list features with $c->features.
 
 This is how this class implements the required interfaces from the role L<CatalystX::Features::Role::Feature>.
 
-=head2 $c->id
+=head2 id
 
 For a feature directory of "my.feature_1.0", the id part is "my.feature_1.0".
 
-=head2 $c->name
+=head2 name
 
 For a feature directory of "my.feature_1.0", the name is "my.feature".
 
-=head2 $c->version
+=head2 version
 
 For a feature directory of "my.feature_1.0", the version is "1.0".
 
-=head2 $c->version_number
+=head2 version_number
 
 A version long integer that can be compared easily. For a feature directory of "my.feature_1.2.3", the version number equals 001002003.
 
@@ -105,7 +107,7 @@ Not everyone want to have this object as a base class for their features. There
 
 =head1 AUTHORS
 
-    Rodrigo de Oliveira (rodrigolive), C<rodrigolive@gmail.com>
+	Rodrigo de Oliveira (rodrigolive), C<rodrigolive@gmail.com>
 
 =head1 LICENSE
 
